@@ -6,7 +6,7 @@ PROJECT_DIR="$(dirname "$(dirname "$(readlink -f "$0")")")"
 
 rm -f "$PROJECT_DIR"/wheelhouse/* || true
 
-for PLATFORM in manylinux2014_i686 manylinux2010_x86_64 manylinux2014_x86_64; do
+for PLATFORM in manylinux_2_24_i686 manylinux2010_x86_64 manylinux_2_24_x86_64; do
     echo -e "\e[32mStarting $PLATFORM\e[0m"
     DOCKER_IMAGE="quay.io/pypa/$PLATFORM"
     docker pull "$DOCKER_IMAGE"
