@@ -1,6 +1,8 @@
 """
 Antidote has a global container which is managed in this module.
 """
+from __future__ import annotations
+
 import threading
 from contextlib import contextmanager
 from typing import Callable, Iterator, Optional
@@ -19,8 +21,10 @@ def current_container() -> RawContainer:
 def current_overridable_container() -> OverridableRawContainer:
     assert __container is not None
     if not isinstance(__container, OverridableRawContainer):
-        raise RuntimeError("Current world does not support overrides. "
-                           "Consider using world.test.clone(override=True)")
+        raise RuntimeError(
+            "Current world does not support overrides. "
+            "Consider using world.test.clone(override=True)"
+        )
     return __container
 
 
@@ -35,6 +39,7 @@ def init() -> None:
     with __container_lock:
         if __container is None:
             from .._internal.world import new_container
+
             __container = new_container()
 
 
