@@ -5,11 +5,12 @@ from typing import Any, Generic, Type, TypeVar
 
 from typing_extensions import Protocol, runtime_checkable
 
+from .marker import Marker
 from .._internal import API
 
-Tct = TypeVar('Tct', contravariant=True)
-Tco = TypeVar('Tco', covariant=True)
-T = TypeVar('T')
+Tct = TypeVar("Tct", contravariant=True)
+Tco = TypeVar("Tco", covariant=True)
+T = TypeVar("T")
 
 
 @API.private
@@ -25,9 +26,9 @@ class Source(Protocol[Tct]):
 @API.private
 class CallableClass(Protocol[Tco]):
     def __call__(self, *args: Any, **kwargs: Any) -> Tco:
-        ...  # pragma: no cover
+        ...
 
 
 @API.private
-class Dependency(Generic[T]):
+class Dependency(Generic[Tco], Marker):
     pass
