@@ -1,4 +1,4 @@
 from . import scopes, test
 from ._methods import debug, freeze, get, lazy, provider
 
-__all__ = ['test', 'scopes', 'freeze', 'get', 'lazy', 'debug', 'provider']
+__all__ = ["test", "scopes", "freeze", "get", "lazy", "debug", "provider"]
