@@ -1,3 +1,3 @@
 from ._methods import new, reset
 
-__all__ = ['new', 'reset']
+__all__ = ["new", "reset"]
