@@ -11,19 +11,19 @@ def test_new_container():
 
 def test_dependency():
     with world.test.empty():
-        world.test.singleton('x', object())
-        d = LazyDependency('x', object)
-        assert d.unwrapped == 'x'
-        assert d.get() is world.get('x')
+        world.test.singleton("x", object())
+        d = LazyDependency("x", object)
+        assert d.unwrapped == "x"
+        assert d.get() is world.get("x")
 
     class A:
         pass
 
     with world.test.empty():
-        world.test.singleton('a', A())
-        world.test.singleton('x', object())
+        world.test.singleton("a", A())
+        world.test.singleton("x", object())
 
-        assert LazyDependency('a', A).get() is world.get('a')
+        assert LazyDependency("a", A).get() is world.get("a")
 
         with pytest.raises(TypeError):
-            LazyDependency('x', A).get()
+            LazyDependency("x", A).get()
