@@ -1,17 +1,11 @@
 import pytest
 
 from antidote import world
-from antidote._providers import (FactoryProvider, IndirectProvider,
-                                 LazyProvider, ServiceProvider)
+from antidote._providers import FactoryProvider, IndirectProvider
 from antidote.core.container import RawProvider
 
 
-@pytest.fixture(params=[
-    FactoryProvider,
-    ServiceProvider,
-    LazyProvider,
-    IndirectProvider
-])
+@pytest.fixture(params=[FactoryProvider, IndirectProvider])
 def provider(request):
     return request.param()
 
