@@ -1,6 +1,6 @@
 from typing import Hashable, Optional
 
-from antidote.core import (Container, DependencyValue, Provider)
+from antidote.core import Container, DependencyValue, Provider
 
 
 class DummyIntProvider(Provider[int]):
@@ -11,8 +11,7 @@ class DummyIntProvider(Provider[int]):
     def exists(self, dependency: Hashable) -> bool:
         return isinstance(dependency, int)
 
-    def provide(self, dependency: int, container: Container
-                ) -> Optional[DependencyValue]:
+    def provide(self, dependency: int, container: Container) -> Optional[DependencyValue]:
         return DependencyValue(dependency * 2)
 
     def clone(self, keep_singletons_cache: bool):
